==> claromentis-framework-9.6.6-26891208.zip: web/intranet/menu/classes/UI/ApplicationsMenu.php <==
<?php
namespace Claromentis\Menu\UI;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] ?: array()) + array("_38dc3c4573d1bf70268680" . "af788c25d2" => base64_decode("bWV" . "udU" . "l0Z" . "W1z"), "_bc051d2e43b6dd0580d9cd86a4" . "eb5b46" => base64_decode("bWVudS9hcHBsaW" . "NhdGlvbnNfbWVu" . "dS5odG1sLnR3aW" . "c="));
use Claromentis\Core\Application;
use Claromentis\Core\Twig\TwigComponent;
use Claromentis\Menu\Infobar\ApplicationsListItems;
use Claromentis\Menu\Infobar\MenuItemFormatter;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Error\SyntaxError;






class ApplicationsMenu extends TwigComponent
{
    private ApplicationsListItems $applicationsListItems;
    private MenuItemFormatter $menuItemFormatter;
    public function __construct(ApplicationsListItems $applicationsListItems, MenuItemFormatter $menuItemFormatter, Environment $_6b67522fca36b32553cd09de29b97ff8, EventDispatcherInterface $dispatcher)
    {
        $this->menuItemFormatter = $menuItemFormatter;
        $this->applicationsListItems = $applicationsListItems;
        parent::__construct($_6b67522fca36b32553cd09de29b97ff8, $dispatcher);
    }
    
    
    
    
    
    
    
    
    
    public function Show($attributes, Application $app)
    {
        $_38dc3c4573d1bf70268680af788c25d2 = $this->applicationsListItems->getDisplayableItems($app->security);
        $_e983106f6b905376cfb3aeed5e5386da = [];
        foreach ($_38dc3c4573d1bf70268680af788c25d2 as $_c5ca63e2f3cceb505a5417b4abb64d55) {
            $_e983106f6b905376cfb3aeed5e5386da[] = $this->menuItemFormatter->toArray($_c5ca63e2f3cceb505a5417b4abb64d55);
        }
        return $this->Render($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_bc051d2e43b" . "6dd0580d9cd8" . "6a4eb5b46"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_38dc3c4573d1bf70268680a" . "f788c25d2"] => $_e983106f6b905376cfb3aeed5e5386da]);
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/menu/classes/UI/ApplicationsMenu.php <==
<?php
namespace Claromentis\Menu\UI;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_38dc3c4573d1bf70" . "268680af788c25d2" => base64_decode("bWV" . "udU" . "l0Z" . "W1z"), "_bc051d2e43b6dd" . "0580d9cd86a4eb5" . "b46" => base64_decode("bWVudS9hcHBsaWNhdGlvbnNfbWVudS5odG1sLnR3aWc" . "="));
use Claromentis\Core\Application;
use Claromentis\Core\Twig\TwigComponent;
use Claromentis\Menu\Infobar\ApplicationsListItems;
use Claromentis\Menu\Infobar\MenuItemFormatter;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Error\SyntaxError;






class ApplicationsMenu extends TwigComponent
{
    private ApplicationsListItems $applicationsListItems;
    private MenuItemFormatter $menuItemFormatter;
    public function __construct(ApplicationsListItems $applicationsListItems, MenuItemFormatter $menuItemFormatter, Environment $_6b67522fca36b32553cd09de29b97ff8, EventDispatcherInterface $dispatcher)
    {
        $this->menuItemFormatter = $menuItemFormatter;
        $this->applicationsListItems = $applicationsListItems;
        parent::__construct($_6b67522fca36b32553cd09de29b97ff8, $dispatcher);
    }
    
    
    
    
    
    
    
    
    
    public function Show($attributes, Application $app)
    {
        $_38dc3c4573d1bf70268680af788c25d2 = $this->applicationsListItems->getDisplayableItems($app->security);
        $_e983106f6b905376cfb3aeed5e5386da = [];
        foreach ($_38dc3c4573d1bf70268680af788c25d2 as $_c5ca63e2f3cceb505a5417b4abb64d55) {
            $_e983106f6b905376cfb3aeed5e5386da[] = $this->menuItemFormatter->toArray($_c5ca63e2f3cceb505a5417b4abb64d55);
        }
        return $this->Render($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_bc051d2e43b6dd0580d9cd86a4eb5b4" . "6"], [$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_38dc3c4573d1bf70268680a" . "f788c25d2"] => $_e983106f6b905376cfb3aeed5e5386da]);
    }
}
